# Electron App

Generated by `pd init electron`.

## Structure

- `/src` contains the main application code.

```bash

```

## Install

In the root directory of the project, run:

```bash
npm install
```

## Run

In the root directory of the project, run:

```bash
npm start
```

## Learn More

To learn Electron, check out the [Electron documentation](https://www.electronjs.org/).